==> curricula-0.0.7-py3-none-any.whl: curricula/grade/test/memory/__init__.py <==
from typing import Optional

from ....library.process import Runtime
from ....library.valgrind import ValgrindReport
from ...task import Result


class MemoryResult(Result):
    """Result of a memory leak test."""

    kind = "memory"

    runtime: Optional[Runtime]
    error_count: Optional[int]
    leaked_blocks: Optional[int]
    leaked_bytes: Optional[int]

    def __init__(
            self,
            passed: bool,
            runtime: Runtime = None,
            complete: bool = True,
            error_count: int = None,
            leaked_blocks: int = None,
            leaked_bytes: int = None,
            **details):
        super().__init__(complete=complete, passed=passed, details=details)
        self.runtime = runtime
        self.error_count = error_count
        self.leaked_blocks = leaked_blocks
        self.leaked_bytes = leaked_bytes

    @classmethod
    def from_valgrind_report(cls, report: ValgrindReport, **details) -> "MemoryResult":
        """Generate a memory test result from a valgrind report."""

        if report.errors is None:
            return cls(complete=False, passed=False, runtime=report.runtime)
        leaked_blocks, leaked_bytes = report.memory_lost()
        return cls(
            passed=leaked_bytes == 0 and len(report.errors) == 0,
            runtime=report.runtime,
            error_count=len(report.errors),
            leaked_blocks=leaked_blocks,
            leaked_bytes=leaked_bytes,
            **details)

    def __str__(self):
        if self.leaked_bytes is None:
            return "failed to run"
        if self.leaked_bytes > 0:
            return f"leaked {self.leaked_bytes} bytes"
        if self.error_count > 0:
            return f"encountered {self.error_count} errors"
        return "found no leaked memory"

    def dump(self) -> dict:
        dump = super().dump()
        dump.update(
            runtime=self.runtime.dump() if self.runtime else None,
            error_count=self.error_count,
            leaked_blocks=self.leaked_blocks,
            leaked_bytes=self.leaked_bytes)
        return dump

==> curricula-0.1.3-py3-none-any.whl: curricula/grade/test/memory/__init__.py <==
from typing import Optional

from ....library.process import Runtime
from ....library.valgrind import ValgrindReport
from ...task import Result, Error


class MemoryResult(Result):
    """Result of a memory leak test."""

    kind = "memory"

    runtime: Optional[Runtime]
    error_count: Optional[int]
    leaked_blocks: Optional[int]
    leaked_bytes: Optional[int]

    def __init__(
            self,
            passing: bool,
            runtime: Runtime = None,
            complete: bool = True,
            error_count: int = None,
            leaked_blocks: int = None,
            leaked_bytes: int = None,
            **details):
        """Initialize a memory result."""

        super().__init__(complete=complete, passing=passing, details=details)
        self.runtime = runtime
        self.error_count = error_count
        self.leaked_blocks = leaked_blocks
        self.leaked_bytes = leaked_bytes

        # Create the error with additional data
        if error_count > 0 or leaked_bytes > 0:
            self.error = Error(description=f"leaked {leaked_bytes} bytes with {error_count} errors")

    @classmethod
    def from_valgrind_report(cls, report: ValgrindReport, **details) -> "MemoryResult":
        """Generate a memory test result from a valgrind report."""

        if report.errors is None:
            return cls(complete=False, passed=False, runtime=report.runtime)
        leaked_blocks, leaked_bytes = report.memory_lost()
        return cls(
            passed=leaked_bytes == 0 and len(report.errors) == 0,
            runtime=report.runtime,
            error_count=len(report.errors),
            leaked_blocks=leaked_blocks,
            leaked_bytes=leaked_bytes,
            **details)

    def dump(self) -> dict:
        dump = super().dump()
        dump.update(
            runtime=self.runtime.dump() if self.runtime else None,
            error_count=self.error_count,
            leaked_blocks=self.leaked_blocks,
            leaked_bytes=self.leaked_bytes)
        return dump
